@@ -1,7 +1,6 @@
-/* $Id$
- *
+/*
  * This file is part of the GIRAFFE Pipeline
- * Copyright (C) 2002-2006 European Southern Observatory
+ * Copyright (C) 2002-2019 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author$
- * $Date$
- * $Revision$
- * $Name$
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -200,7 +192,7 @@ giraffe_slitgeometry_create(GiTable *slitgeometry, cxbool subslits)
     const cxchar *c_ssn = "SSN";
     const cxchar *c_rindex = NULL;
 
-    cxint status;
+    /*cxint status;*/
     cxint nfibers = 0;
     cxint max_nsubslits = 0;
     cxint i             = 0;
@@ -259,12 +251,12 @@ giraffe_slitgeometry_create(GiTable *slitgeometry, cxbool subslits)
             max_nsubslits = _nsubslits;
         }
 
-        status = cpl_matrix_set(self->xf, i, 0, _xf);
-        status = cpl_matrix_set(self->yf, i, 0, _yf);
-        status = cpl_matrix_set(self->fps, i, 0, (cxdouble)_fps);
-        status = cpl_matrix_set(self->rindex, i, 0, (cxdouble)_index);
+        /*status =*/ cpl_matrix_set(self->xf, i, 0, _xf);
+        /*status =*/ cpl_matrix_set(self->yf, i, 0, _yf);
+        /*status =*/ cpl_matrix_set(self->fps, i, 0, (cxdouble)_fps);
+        /*status =*/ cpl_matrix_set(self->rindex, i, 0, (cxdouble)_index);
 
-        status = cpl_matrix_set(nsubslits, i, 0, (cxdouble)_nsubslits);
+        /*status =*/ cpl_matrix_set(nsubslits, i, 0, (cxdouble)_nsubslits);
 
     }
 
@@ -305,7 +297,7 @@ giraffe_slitgeometry_create(GiTable *slitgeometry, cxbool subslits)
 
                 if (i == curr_ssn) {
 
-                    status = cpl_matrix_set(ref_matrix, column_index, 0,
+                    /*status =*/ cpl_matrix_set(ref_matrix, column_index, 0,
                                             (cxdouble)j);
                     ++column_index;
                 }
@@ -328,7 +320,7 @@ giraffe_slitgeometry_create(GiTable *slitgeometry, cxbool subslits)
 
         for (j = 0; j < nfibers; j++) {
 
-            status = cpl_matrix_set(ref_matrix, j, 0, (cxdouble)j);
+            /*status =*/ cpl_matrix_set(ref_matrix, j, 0, (cxdouble)j);
 
         }
 
@@ -336,6 +328,8 @@ giraffe_slitgeometry_create(GiTable *slitgeometry, cxbool subslits)
 
     }
 
+    cpl_matrix_delete(nsubslits);
+
     return self;
 
 }
