@@ -1,7 +1,6 @@
-/* $Id$
- *
+/*
  * This file is part of the GIRAFFE Pipeline
- * Copyright (C) 2002-2006 European Southern Observatory
+ * Copyright (C) 2002-2019 European Southern Observatory
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +17,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-/*
- * $Author$
- * $Date$
- * $Revision$
- * $Name$
- */
-
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
@@ -42,6 +34,7 @@
 #include <cpl_msg.h>
 #include <cpl_error.h>
 #include <cpl_matrix.h>
+#include <cpl_version.h>
 
 #include "gialias.h"
 #include "gimessages.h"
@@ -270,6 +263,147 @@ _giraffe_add_frame_info(cpl_propertylist *plist, const cxchar *name,
 }
 
 
+inline static cxint
+_giraffe_add_option_info(cpl_propertylist *plist,
+                         const cpl_parameterlist *options, cxint sequence)
+{
+    cx_assert(plist != NULL);
+    cx_assert(options != NULL);
+    cx_assert(sequence >= 1);
+
+    cx_string *key = cx_string_new();
+    cx_string *comment = cx_string_new();
+
+    cxint pcount = 0;
+    const cpl_parameter *p = cpl_parameterlist_get_first_const(options);
+
+    if (p == NULL) {
+        cx_string_delete(key);
+        cx_string_delete(comment);
+        return 1;
+    }
+
+    while (p != NULL) {
+
+        cxint status = 0;
+        const cxchar *alias = cpl_parameter_get_alias(p, CPL_PARAMETER_MODE_CLI);
+        cx_string *value = cx_string_new();
+        cx_string *preset = cx_string_new();
+
+        switch (cpl_parameter_get_type(p)) {
+            case CPL_TYPE_BOOL:
+            {
+                int bval = cpl_parameter_get_bool(p);
+                cx_string_sprintf(value, "%s", (bval == 1) ? "true" : "false");
+
+                bval = cpl_parameter_get_default_bool(p);
+                cx_string_sprintf(preset, "%s", (bval == 1) ? "true" : "false");
+                break;
+            }
+            case CPL_TYPE_INT:
+            {
+                cx_string_sprintf(value, "%d", cpl_parameter_get_int(p));
+                cx_string_sprintf(preset, "%d", cpl_parameter_get_default_int(p));
+                break;
+            }
+            case CPL_TYPE_DOUBLE:
+            {
+                cx_string_sprintf(value, "%g", cpl_parameter_get_double(p));
+                cx_string_sprintf(preset, "%g", cpl_parameter_get_default_double(p));
+                break;
+            }
+            case CPL_TYPE_STRING:
+            {
+                cx_string_sprintf(value, "%s", cpl_parameter_get_string(p));
+                cx_string_sprintf(preset, "%s", cpl_parameter_get_default_string(p));
+                break;
+            }
+            default:
+            {
+                /* Unsupported parameter type */
+                status = -1;
+                break;
+            }
+        }
+
+        if (status != 0) {
+            cx_string_delete(key);
+            cx_string_delete(comment);
+            cx_string_delete(value);
+            cx_string_delete(preset);
+
+            return -1;
+        }
+
+        ++pcount;
+        cx_string_sprintf(key, "%s%-d %s%-d %s", "ESO PRO REC", sequence,
+                          "PARAM", pcount, "NAME");
+        status = cpl_propertylist_update_string(plist, cx_string_get(key), alias);
+
+        if (status != 0) {
+            cx_string_delete(key);
+            cx_string_delete(comment);
+            cx_string_delete(value);
+            cx_string_delete(preset);
+
+            return 2;
+        }
+
+        status = cpl_propertylist_set_comment(plist, cx_string_get(key),
+                                              cpl_parameter_get_help(p));
+
+        if (status != 0) {
+            cx_string_delete(key);
+            cx_string_delete(comment);
+            cx_string_delete(value);
+            cx_string_delete(preset);
+
+            return 2;
+        }
+
+
+        cx_string_sprintf(key, "%s%-d %s%-d %s", "ESO PRO REC", sequence,
+                          "PARAM", pcount, "VALUE");
+        cx_string_sprintf(comment, "Default: %s", cx_string_get(preset));
+
+        status = cpl_propertylist_update_string(plist, cx_string_get(key),
+                                                cx_string_get(value));
+
+        if (status != 0) {
+            cx_string_delete(key);
+            cx_string_delete(comment);
+            cx_string_delete(value);
+            cx_string_delete(preset);
+
+            return 3;
+        }
+
+        status = cpl_propertylist_set_comment(plist, cx_string_get(key),
+                                              cx_string_get(comment));
+
+        if (status != 0) {
+            cx_string_delete(key);
+            cx_string_delete(comment);
+            cx_string_delete(value);
+            cx_string_delete(preset);
+
+            return 3;
+        }
+
+        cx_string_delete(value);
+        cx_string_delete(preset);
+
+        p = cpl_parameterlist_get_next_const(options);
+
+    }
+
+    cx_string_delete(key);
+    cx_string_delete(comment);
+
+    return 0;
+}
+
+
 /**
  * @brief
  *   Get the pipeline copyright and license.
@@ -501,6 +635,31 @@ giraffe_add_recipe_info(cpl_propertylist *plist, const GiRecipeInfo *info)
         cx_string *value = cx_string_new();
 
 
+        cx_string_sprintf(name, "%s%-d %s", "ESO PRO REC", info->sequence,
+                          "ID");
+        cx_string_sprintf(value, "%s", info->recipe);
+
+        status = cpl_propertylist_update_string(plist, cx_string_get(name),
+                                                cx_string_get(value));
+
+
+        if (status != CPL_ERROR_NONE) {
+            cx_string_delete(name);
+            cx_string_delete(value);
+
+            return 1;
+        }
+
+        status = cpl_propertylist_set_comment(plist, cx_string_get(name),
+                                       "Pipeline recipe (unique) identifier");
+
+        if (status != 0) {
+            cx_string_delete(name);
+            cx_string_delete(value);
+
+            return 1;
+        }
+
         cx_string_sprintf(name, "%s%-d %s", "ESO PRO REC", info->sequence,
                           "PIPE ID");
         cx_string_sprintf(value, "%s/%s", PACKAGE, VERSION);
@@ -526,6 +685,31 @@ giraffe_add_recipe_info(cpl_propertylist *plist, const GiRecipeInfo *info)
             return 1;
         }
 
+        cx_string_sprintf(name, "%s%-d %s", "ESO PRO REC", info->sequence,
+                          "DRS ID");
+        cx_string_sprintf(value, "cpl-%s", cpl_version_get_version());
+
+        status = cpl_propertylist_update_string(plist, cx_string_get(name),
+                                                cx_string_get(value));
+
+
+        if (status != CPL_ERROR_NONE) {
+            cx_string_delete(name);
+            cx_string_delete(value);
+
+            return 1;
+        }
+
+        status = cpl_propertylist_set_comment(plist, cx_string_get(name),
+                                       "Data Reduction System identifier");
+
+        if (status != 0) {
+            cx_string_delete(name);
+            cx_string_delete(value);
+
+            return 1;
+        }
+
         if (info->start != NULL) {
             cx_string_sprintf(name, "%s%-d %s", "ESO PRO REC",
                               info->sequence, "START");
@@ -555,6 +739,17 @@ giraffe_add_recipe_info(cpl_propertylist *plist, const GiRecipeInfo *info)
         cx_string_delete(name);
         cx_string_delete(value);
 
+
+        /*
+         *  Add recipe options
+         */
+
+        status = _giraffe_add_option_info(plist, info->options, info->sequence);
+
+        if (status != 0) {
+            return 1;
+        }
+
     }
 
     return 0;
