@@ -1,6 +1,12 @@
+# ========================================================================================================
+#
+# John Pritchard
+#
 ## This script allows a user to run the workflow without AstroScrappy installed,
 ## then install AstroScrappy and re-run the workflow and then get the AstroScrappy
 ## results without having to remove the previous execution
+#
+# ========================================================================================================
 
 # import the required modules
 import reflex 
@@ -17,7 +23,7 @@ try:
 
 except ImportError:
     import_sucess = False
-    print "Error importing one or more of the astroscrappy"
+    print("Error importing one or more of the astroscrappy")
 
 if __name__ == '__main__':
   
